@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2021-10-14 16:43:54
+:LastEditTime: 2021-10-14 19:00:36
 :LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
@@ -462,10 +462,16 @@ def login_filter(is_need_login=True, optional_params=None):
                 if not user_login or TimeHelper.format_time_to_datetime(user_login["ExpireTime"]) < TimeHelper.get_now_datetime():
                     if not is_need_login:
                         return
+                    self.clear_cookie("UserID")
+                    self.clear_cookie("UserIDMD5")
+                    self.clear_cookie("UserToken")
                     return self.reponse_common("UserExpire", "用户已过期，请重新登录")
                 if user_login["UserToken"] != user_token:
                     if not is_need_login:
                         return
+                    self.clear_cookie("UserID")
+                    self.clear_cookie("UserIDMD5")
+                    self.clear_cookie("UserToken")
                     return self.reponse_common("DeviceExpire", "用户在其他终端登录")
 
                 curr_user_info = UserInfoModel(config.get_value("manage_context_key")).get_entity_by_id(user_id)
@@ -481,10 +487,16 @@ def login_filter(is_need_login=True, optional_params=None):
                 if not user_login or TimeHelper.format_time_to_datetime(user_login.ExpireTime) < TimeHelper.get_now_datetime():
                     if not is_need_login:
                         return
+                    self.clear_cookie("UserID")
+                    self.clear_cookie("UserIDMD5")
+                    self.clear_cookie("UserToken")
                     return self.reponse_common("UserExpire", "用户已过期，请重新登录")
                 if user_login.UserToken != user_token:
                     if not is_need_login:
                         return
+                    self.clear_cookie("UserID")
+                    self.clear_cookie("UserIDMD5")
+                    self.clear_cookie("UserToken")
                     return self.reponse_common("DeviceExpire", "用户在其他终端登录")
 
                 manage_context_key = self.get_manage_context_key()
